summaryrefslogtreecommitdiff
path: root/src/mongo/db/pipeline/expression.cpp
diff options
context:
space:
mode:
authorNathan Brown <nathan.brown@10gen.com>2019-06-06 10:39:58 -0400
committerNathan Brown <nathan.brown@10gen.com>2019-06-27 10:04:18 -0400
commit0fefcf84347a2bcc4961baec0295b9d04047d86f (patch)
treece86921e5b14ee83a00400f4f4e8712093505cb8 /src/mongo/db/pipeline/expression.cpp
parenta700238800aa2bf1e10c255337ec35373ffd2667 (diff)
downloadmongo-0fefcf84347a2bcc4961baec0295b9d04047d86f.tar.gz
SERVER-7143 replace standard library number parsing with custom NumberParser
Diffstat (limited to 'src/mongo/db/pipeline/expression.cpp')
-rw-r--r--src/mongo/db/pipeline/expression.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mongo/db/pipeline/expression.cpp b/src/mongo/db/pipeline/expression.cpp
index 8dfd63eb547..8b641f35fda 100644
--- a/src/mongo/db/pipeline/expression.cpp
+++ b/src/mongo/db/pipeline/expression.cpp
@@ -5527,14 +5527,14 @@ private:
targetType result;
// Reject any strings in hex format. This check is needed because the
// parseNumberFromStringWithBase call below allows an input hex string prefixed by '0x' when
// parsing to a double.
uassert(ErrorCodes::ConversionFailure,
str::stream() << "Illegal hexadecimal input in $convert with no onError value: "
<< stringValue,
!stringValue.startsWith("0x"));
- Status parseStatus = parseNumberFromStringWithBase(stringValue, base, &result);
+ Status parseStatus = NumberParser().base(base)(stringValue, &result);
uassert(ErrorCodes::ConversionFailure,
str::stream() << "Failed to parse number '" << stringValue
<< "' in $convert with no onError value: "
@@ -5527,14 +5527,14 @@ private:
targetType result;
// Reject any strings in hex format. This check is needed because the
- // parseNumberFromStringWithBase call below allows an input hex string prefixed by '0x' when
+ // NumberParser::parse call below allows an input hex string prefixed by '0x' when
// parsing to a double.
uassert(ErrorCodes::ConversionFailure,